@@ -1,5 +1,6 @@
 #   Copyright (c) 2006-2007 Open Source Applications Foundation
 #   Copyright (c) 2008-2009 Mikeal Rogers <mikeal.rogers@gmail.com>
+#   Copyright (c) 2009 Canonical Ltd.
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -21,7 +22,7 @@ from datetime import datetime
 from threading import Thread
 import shutil
 import socket
-import functest
+from windmill.dep import functest
 functest.configure()
 
 def process_options(argv_list):
@@ -121,6 +122,8 @@ def configure_global_settings(logging_on=True):
         local_settings = None
 
     windmill.settings = windmill.conf.configure_settings(localSettings=local_settings)
+    if 'controllers' not in windmill.settings:
+        windmill.settings['controllers'] = []
     
     port = windmill.settings['SERVER_HTTP_PORT']
     
@@ -202,24 +205,12 @@ def teardown(shell_objects):
         for directory in windmill.teardown_directories:
             if os.path.isdir(directory):
                 shutil.rmtree(directory)
-
-        # while shell_objects['httpd_thread'].isAlive():
-        #     try:
-        #         shell_objects['httpd'].stop()
-        #     except Exception, e:
-        #         print "Exception occurred while shutting server down:"
-        #         print e
-        #         
-        #     # Hacking workaround for port locking up on linux.
-        #     if sys.platform == 'linux2':
-        #         try:
-        #             shell_objects['httpd'].socket.shutdown(socket.SHUT_RDWR)
-        #             shell_objects['httpd'].socket.close()
-        #         except: pass
         
         shell_objects['httpd'].stop()
-        #shell_objects['httpd_thread'].join()
         
+        # We had a ton of code here for killing the process
+        # But I removed it all and things seem to work
+        # Guess we can revert if it's broken :)
 
 def runserver_action(shell_objects):
     """Run the server in the foreground with the options given to the command line"""
