@@ -15,12 +15,12 @@
 #   limitations under the License.
 
 import windmill
-import uuid
+from windmill.dep import uuid
 import sys, os, logging, re
 from time import sleep
 from windmill.authoring import frame
 from threading import Thread
-import functest
+from windmill.dep import functest
 
 logger = logging.getLogger(__name__)
 
@@ -43,7 +43,8 @@ def start_firefox():
     """Start the Firefox web browser configured for windmill"""
     controller = windmill.browser.get_firefox_controller()
     controller.start()
-    print 'Started '+str(controller.command)
+    #print 'Started '+str(controller.command)
+    logger.info(str(controller.command))
     windmill.settings['controllers'].append(controller)
     return controller
     
@@ -62,7 +63,7 @@ def start_safari():
     return controller
     
 def start_chrome():
-    """Start the Crhome web browser configured for windmill"""
+    """Start the Chrome web browser configured for windmill"""
     controller = windmill.browser.get_chrome_controller()
     controller.start()
     windmill.settings['controllers'].append(controller)
@@ -131,11 +132,11 @@ def do_test(filename, load=False, threaded=True):
             sleep(1)
         run_functest()
 
-run_test = lambda filename : do_test(filename, load=False)
+run_test = lambda filename : do_test(filename, load=False, threaded=True)
 run_test.__name__ = 'run_test'
 run_test.__doc__ = "Run the test file or directory passed to this function"
 
-load_test = lambda filename : do_test(filename, load=True)    
+load_test = lambda filename : do_test(filename, load=True, threaded=True)    
 load_test.__name__ = 'load_test'
 load_test.__doc__ = "Load the test file or directory passed to this function"   
 
@@ -143,7 +144,8 @@ def run_js_tests(js_dir, test_filter=None, phase=None):
     import windmill
     windmill.js_framework_active = True
     js_dir = os.path.abspath(os.path.expanduser(js_dir))
-    from wsgi_fileserver import WSGIFileServerApplication
+    from windmill.dep import wsgi_fileserver  
+    WSGIFileServerApplication = wsgi_fileserver.WSGIFileServerApplication
     application = WSGIFileServerApplication(root_path=os.path.abspath(js_dir), mount_point='/windmill-jstest/')
     from windmill.server import wsgi
     wsgi.add_namespace('windmill-jstest', application)
@@ -164,13 +166,21 @@ def run_js_tests(js_dir, test_filter=None, phase=None):
         kwargs['filter'] = test_filter
     if phase:
         kwargs['phase'] = phase
+    
+    xmlrpc_client.add_command({
+      'method':'commands.setOptions',
+      'params': {
+        'scriptAppendOnly': windmill.settings['SCRIPT_APPEND_ONLY']
+      }
+    })
     xmlrpc_client.add_command({'method':'commands.jsTests', 'params':kwargs})
     
 
 def load_extensions_dir(dirname):
    """Mount the directory and send all javascript file links to the IDE in order to execute those test urls under the jsUnit framework"""
    # Mount the fileserver application for tests
-   from wsgi_fileserver import WSGIFileServerApplication
+   from windmill.dep import wsgi_fileserver
+   WSGIFileServerApplication = wsgi_fileserver.WSGIFileServerApplication
    application = WSGIFileServerApplication(root_path=os.path.abspath(dirname), mount_point='/windmill-extentions/')
    from windmill.server import wsgi
    wsgi.add_namespace('windmill-extentions', application)
