@@ -57,6 +57,7 @@ START_CHROME        = False
 JAVASCRIPT_TEST_DIR = None
 JAVASCRIPT_TEST_FILTER = None
 JAVASCRIPT_TEST_PHASE = None
+SCRIPT_APPEND_ONLY = False
 
 # Browser prefs
 # MOZILLA_COMMAND = None
@@ -80,6 +81,7 @@ if PLATFORM == 'darwin':
     # MOZILLA_DEFAULT_PROFILE = os.path.join(firefoxDir, 'Contents', 'MacOS', 'defaults', 'profile')
     # MOZILLA_BINARY          = os.path.join(firefoxDir, 'Contents', 'MacOS', 'firefox-bin')
     SAFARI_BINARY           = '/Applications/Safari.app/Contents/MacOS/Safari'
+    CHROME_BINARY           = '/Applications/Google Chrome.app/Contents/MacOS/Google Chrome'
     
     import distutils.version, commands
     OS_VERSION = distutils.version.StrictVersion(commands.getoutput('sw_vers -productVersion'))
@@ -93,7 +95,11 @@ if PLATFORM == 'darwin':
         elif os.path.isfile(os.path.join(networksetup_base, 'networksetup-panther')):
             NETWORKSETUP_BINARY = os.path.join(networksetup_base, 'networksetup-panther')
 
-# elif sys.platform == 'linux2':
+elif sys.platform == 'linux2':
+    #Get Chrome bin for linux
+    chromebin = findInPath('google-chrome')
+    if chromebin and os.path.isfile(chromebin):
+        CHROME_BINARY=chromebin
 #     firefoxBin = findInPath('firefox')
 # 
 #     if firefoxBin is not None and os.path.isfile(firefoxBin):
@@ -115,8 +121,8 @@ elif sys.platform in ('cygwin', 'win32'):
     if os.path.isfile(os.path.join(program_files, 'Safari', 'Safari.exe')):
         SAFARI_BINARY = os.path.join(program_files, 'Safari', 'Safari.exe')
         
-    if os.path.isfile(os.path.join(os.path.expanduser('~'), 'Local Settings', 'Application Data', 'Google', 'Chrome', 'Application', 'chrome.exe')):
-        CHROME_BINARY = os.path.join(os.path.expanduser('~'), 'Local Settings', 'Application Data', 'Google', 'Chrome', 'Application', 'chrome.exe')
+    if os.path.isfile(os.path.join(os.environ['USERPROFILE'], 'Local Settings', 'Application Data', 'Google', 'Chrome', 'Application', 'chrome.exe')):
+        CHROME_BINARY = os.path.join(os.environ['USERPROFILE'], 'Local Settings', 'Application Data', 'Google', 'Chrome', 'Application', 'chrome.exe')
     
     # firefoxBin = findInPath('firefox')
     # 
