@@ -28,30 +28,28 @@ var jsonCall = function(version, method, params) {
 
 
 //Translates from the way we are passing objects to functions to the lookups
-var lookupNode = function (paramObject, throwErr){
-  if (typeof(throwErr) == "undefined"){
-    var throwErr = false;
-  }
+var lookupNode = function (paramObject, scroll){
   
   var s = null;
   var element = null;
+  
   //If a link was passed, lookup as link
   if(typeof paramObject.link != "undefined") {
     s = 'Looking up link '+ paramObject.link;
     element = elementslib.Element.LINK(paramObject.link);
   }
   //if xpath was passed, lookup as xpath
-  if(typeof paramObject.xpath != "undefined") {
+  else if(typeof paramObject.xpath != "undefined") {
     s = 'Looking up xpath '+ paramObject.xpath;        
     element = elementslib.Element.XPATH(paramObject.xpath);
   }
   //if id was passed, do as such
-  if(typeof paramObject.id != "undefined") {
+  else if(typeof paramObject.id != "undefined") {
     s = 'Looking up id '+ paramObject.id;
     element = elementslib.Element.ID(paramObject.id);
   }
   //if jsid was passed
-  if(typeof paramObject.jsid != "undefined") {
+  else if(typeof paramObject.jsid != "undefined") {
     //Here if the user hasn't specified the test window scope
     //we use the default and prepend it, else we eval whatever js they passed
     var jsid = windmill.testWin().eval(paramObject.jsid);
@@ -60,43 +58,129 @@ var lookupNode = function (paramObject, throwErr){
     element = elementslib.Element.ID(jsid);
   }
   //if name was passed
-  if(typeof paramObject.name != "undefined") {
+  else if(typeof paramObject.name != "undefined") {
     s = 'Looking up name '+ paramObject.name;
     element = elementslib.Element.NAME(paramObject.name);
   }
   //if value was passed
-  if(typeof paramObject.value != "undefined") {
+  else if(typeof paramObject.value != "undefined") {
     s = 'Looking up value '+ paramObject.value;
     element = elementslib.Element.VALUE(paramObject.value);
   }
   //if classname was passed
-  if(typeof paramObject.classname != "undefined") {
+  else if(typeof paramObject.classname != "undefined") {
     s = 'Looking up classname '+ paramObject.classname;
     element = elementslib.Element.CLASSNAME(paramObject.classname);
   }
   //if tagname was passed
-  if(typeof paramObject.tagname != "undefined") {
+  else if(typeof paramObject.tagname != "undefined") {
     s = 'Looking up tagname '+ paramObject.tagname;
     element = elementslib.Element.TAGNAME(paramObject.tagname);
   }
   //if label was passed
-  if(typeof paramObject.label != "undefined") {
+  else if(typeof paramObject.label != "undefined") {
     s = 'Looking up label '+ paramObject.label;
     element = elementslib.Element.LABEL(paramObject.label);
   }
+  //if jquery was passed
+  else if(typeof paramObject.jquery != "undefined") {
+    s = 'Looking up jquery selector '+ paramObject.jquery;
+    paramObject.jquery = windmill.helpers.replaceAll(paramObject.jquery, ").", ")<*>");
+    var jQ = jQuery(windmill.testWin().document);
+    var chain= paramObject.jquery.split('<*>');
+    
+    paramObject.jquery = windmill.helpers.replaceAll(paramObject.jquery, "<*>", ".");
+    var start = eval('jQ.find'+chain[0]);
+    var theRest = paramObject.jquery.replace(chain[0],'');
+    element = eval('start'+theRest);
+  }
+  else if(typeof paramObject.jqueryframe != "undefined" && typeof paramObject.frameid != "undefined") {
+    s = 'Looking up jqueryframe selector '+paramObject.jqueryframe;
+    paramObject.jqueryframe = windmill.helpers.replaceAll(paramObject.jqueryframe, ").", ")<*>");
+    var jQ = jQuery(windmill.testWin().document.getElementById(paramObject.frameid).contentWindow.document)
+    var chain= paramObject.jqueryframe.split('<*>');
+    paramObject.jqueryframe = windmill.helpers.replaceAll(paramObject.jqueryframe, "<*>", ".");
+    var start = eval('jQ.find'+chain[0]);
+    var theRest = paramObject.jqueryframe.replace(chain[0],'');
+    element = eval('start'+theRest);
+  }
+  else if(typeof paramObject.string != "undefined"){
+  	s = "Looking up nodes containing text "+ paramObject.string;
+    var nodes = jQuery(windmill.testWin().document.body).find("*:contains('"+paramObject.string+"')");
+		element = nodes[nodes.length - 1];
+	}
+  else if(typeof paramObject.rteID != "undefined"){
+    s = 'Looking up rte selector '+ paramObject.rte;
+    element = lookupNode({id:paramObject.rteID}).contentWindow.document.body; 
+  }
+  else {
+    return false;
+  }
   //scroll so that the element is in view
   if (element) { 
-    //if the element you accessed is a flash object
+    //if the element you accessed is a flex object
     //the scroll into view will actually fail and 
     //throw a crazy DOM exception
-    try {
-      element.scrollIntoView(); 
-    } catch(err){}
-    
+    if (scroll != false){
+      try {
+        element.scrollIntoView(); 
+      } catch(err){}
+    }
     return element;
   }
-  else if (throwErr == true) { throw s + ", failed."; }
-  else{ lookupNode(paramObject, true); }
+  else { throw s + ", failed."; }
+};
+
+var arrayToJSPath = function(arr){
+  var s = arr.toString();
+  var path = windmill.helpers.replaceAll(s, ",", ".");
+  return path;
+};
+
+var stringToFunc = function (objPathString) {
+  var arr = objPathString.split('.');
+  var win = windmill.controller;
+  var baseObj;
+  var parseObjPath = function (name) {
+    baseObj = !name ? win : baseObj[name];
+    if (!baseObj) {
+      var errMsg = 'Method "' + objPathString + '" does not exist.';
+      // The syntax-error possibility is only for browsers with
+      // a broken eval (IE, Safari 2) -- the script-append hack
+      // blindly sets the text of the script without checking syntax
+      throw new Error(errMsg);
+    }
+    return arr.length ? parseObjPath(arr.shift()) : baseObj;
+  };
+  // call parseObjPath recursively to append each
+  // property/key onto the window obj from the array
+  // 'foo.bar.baz' => arr = ['foo', 'bar', 'baz']
+  // baseObj = window['foo'] =>
+  // baseObj = window['foo']['bar'] =>
+  // baseObj = window['foo']['bar']['baz']
+  return parseObjPath();
+};
+
+//visually display a node on the page
+var show = function(obj){
+  //if we receive a node, use that
+  //if we get a locator, use that
+  if (obj.nodeType){ elem = obj; }
+  else { var elem = lookupNode(obj); }
+  
+  //use outline in FF, and border in IE
+  var prop = windmill.ui.hilightProp;
+  
+  //reset the outline/border when done
+  var reset = function(e){
+    elem.style[windmill.ui.hilightProp] = "";
+  }
+  
+  //blink the node
+  if (elem){
+    elem.style[windmill.ui.hilightProp] = "4px solid orange";
+    jQuery(elem).fadeOut(700).fadeIn(700).fadeOut(700).fadeIn(1000, reset);    
+  }
 };
 
 //Function to handle the random keyword scenario
@@ -107,7 +191,7 @@ var handleVariable = function (val){
     for (var i = 0; i < matches.length; i++){
       var m = matches[i];
       if (windmill.varRegistry.hasKey(m)){
-        ret = windmill.helpers.replaceAll(ret, m, windmill.varRegistry.getByKey(m));
+        ret = windmill.helpers.replaceAll(ret, m, removeHTMLTags(windmill.varRegistry.getByKey(m)));
       }
       //if it doesn't exist and contains the string random we create it (username or pass etc)
       else if (m.indexOf('random') != -1){
@@ -164,12 +248,16 @@ var busyOff = function(){
 //     $('ide').style.display = 'block';
 // };
 
+var updateSpeed = function(){
+  windmill.serviceDelay = $('execSpeed').value;
+};
+
 var openSettings = function() {
     //Turn off explorers and recorder
     windmill.ui.recorder.recordOff();
-    windmill.ui.domexplorer.domExplorerOff();
+    windmill.ui.dx.domExplorerOff();
     windmill.ui.assertexplorer.assertExplorerOff();
-
+    $('execSpeed').value = windmill.serviceDelay;
     //$(id).style.display = 'block';
     jQuery("#dialog").dialog('open');
     // $('ide').style.display = 'none';
@@ -216,7 +304,7 @@ var resetDD = function(){
 
 var toggleRec = function() {
     if ($('record').src.indexOf("img/record.png") != -1) {
-        windmill.ui.domexplorer.domExplorerOff();
+        windmill.ui.dx.domExplorerOff();
         windmill.ui.assertexplorer.assertExplorerOff();
         windmill.ui.recorder.recordOn();
         windmill.testWin().focus();
@@ -261,13 +349,13 @@ var toggleExplore = function() {
         if (windmill.ui.recorder.recordState == true) { toggleRec(); }
         $('domExp').style.visibility = 'visible';
         $('domExp').innerHTML = '';
-        windmill.ui.domexplorer.domExplorerOn();
+        windmill.ui.dx.domExplorerOn();
         windmill.testWin().focus();
         $('explorer').src = 'img/xoff.png';
     }
     else {
         $('domExp').style.visibility = 'hidden';
-        windmill.ui.domexplorer.domExplorerOff();
+        windmill.ui.dx.domExplorerOff();
         $('explorer').src = 'img/xon.png';
         $('domExp').innerHTML = '';
     }
@@ -622,4 +710,4 @@ var getParentWindow = function(node){
   }
   
   return win;
-};
\ No newline at end of file
+};
