@@ -15,7 +15,7 @@ Copyright 2006-2007, Open Source Applications Foundation
 */
 
 //DOM Explorer Functions
-windmill.ui.domexplorer = new function() {
+windmill.ui.dx = new function() {
   var exploreState = false;
   
   this.setExploreState = function() {
@@ -28,14 +28,8 @@ windmill.ui.domexplorer = new function() {
   
   //Display the id in the remote
   this.setIdInRemote = function(e) {
-    if ($(windmill.ui.remote.selectedElement) == null){
-      windmill.ui.remote.selectedElement = null;
-    }
-    if (windmill.ui.remote.selectedElement != null) {
-      $("domExp").style.display = 'none';
-    }
-    if (windmill.ui.remote.selectedElementOption != null) {
-      $("domExp").style.display = 'none';
+    if ($(windmill.ui.remote.selectedInputID) == null){
+      windmill.ui.remote.selectedInputID = null;
     }
     
     //if absolute xpath is not wanted try our best to get a better locater
@@ -93,65 +87,64 @@ windmill.ui.domexplorer = new function() {
       }
       
       //trying to keep old borders from getting left all over the page
-      if (windmill.ui.domexplorer.currElem){
-          //sometimes IE doesn't like this
-          try{
-            windmill.ui.domexplorer.currElem.style[windmill.ui.hilightProp] = "";
-          }
-          catch(err){}
+      if (windmill.ui.dx.currElem){
+        //sometimes IE doesn't like this
+        try {
+          windmill.ui.dx.currElem.style[windmill.ui.hilightProp] = "";
+        } catch(err){}
       }
       
       e.target.style[windmill.ui.hilightProp] = windmill.ui.borderHilight;
-      windmill.ui.domexplorer.currElem = e.target;
+      windmill.ui.dx.currElem = e.target;
       
       this.explorerUpdate(e);
   };
+  
+  this.parseDOMExp = function(){
+    var a = $("domExp").innerHTML.split(': ');
+    //If the element is a link, get rid of the all the garbage
+    if (a[0] == 'link') {
+      a[1] = a[1].replace(/(<([^>]+)>)/ig, "");
+      a[1] = a[1].replace(/\n/g, "");
+    }
+    return a;
+  };
+  
+  this.updateAction = function(){
+    var a = this.parseDOMExp();
+    a[0] = a[0].toLowerCase();
 
+    if (windmill.ui.remote.selectedInputID) {
+      var id = windmill.ui.remote.selectedInputID;
+      var input = $(id);
+      
+      //Sometimes there isnt a drop down, just a span
+      try {
+        var dd = $(id+"Type");
+        if (dd.value.indexOf('opt') != -1){
+          dd.value = "opt"+a[0];
+        }
+        else {
+          dd.value = a[0];
+        }
+      }
+      catch(err){ windmill.err(err); }
+      
+      input.value = a[1];
+      input.focus();
+    }
+  };
+  
   this.explorerUpdate = function(e) {
     e.cancelBubble = true;
     if (windmill.browser.isIE == false) {
+      try {
         e.stopPropagation();
         e.preventDefault();
-    }
-    if (windmill.ui.remote.selectedElementOption != null && e.altKey == false) {
-        var id = windmill.ui.remote.selectedElementOption.replace('option', '');
-        //Incase if that node has been removed somehow
-        try {
-          var a = $("domExp").innerHTML.split(': ');
-          //If the element is a link, get rid of the all the garbage
-          if (a[0] == 'link') {
-              a[1] = a[1].replace(/(<([^>]+)>)/ig, "");
-              a[1] = a[1].replace(/\n/g, "");
-          }
-          $(id + 'optionType').value = 'opt'+a[0].toLowerCase();
-          $(id + 'option').value = a[1];
-          $(id + 'option').focus();
-        }
-        catch(error) {
-          windmill.err('Error in dom explorer');
-        }
-    }
-    
-    if (windmill.ui.remote.selectedElement != null) {
-        var id = windmill.ui.remote.selectedElement.replace('locator', '');
-        
-        //Incase if that node has been removed somehow
-        try {
-          var a = $("domExp").innerHTML.split(': ');
-          //If the element is a link, get rid of the all the garbage
-          if (a[0] == 'link') {
-              a[1] = a[1].replace(/(<([^>]+)>)/ig, "");
-              a[1] = a[1].replace(/\n/g, "");
-          }
-          $(id + 'locatorType').value = a[0].toLowerCase();
-          $(id + 'locator').value = a[1];
-          $(id + 'locator').focus();
-        }
-        catch(error) {
-          windmill.err('Error in dom explorer');
-        }
+      } catch(err){}
     }
     
+    this.updateAction();
   };
   
   this.showMouseCoords = function(e){
@@ -165,7 +158,7 @@ windmill.ui.domexplorer = new function() {
       e.preventDefault();
     }
     
-    var optId = windmill.ui.remote.selectedElementOption;
+    var optId = windmill.ui.remote.selectedInputID;
     //if an option section is selected and the altKey is down append the mouse coords
     if ((optId != null) && (e.altKey)){
       if ($(optId).value == ""){
@@ -176,26 +169,26 @@ windmill.ui.domexplorer = new function() {
       }
     }
     else {
-      if ($("domExp").style.display == 'none'){
-        windmill.ui.domexplorer.domExplorerOff();
-      } else {
-        windmill.ui.domexplorer.dxRecursiveUnBind(windmill.testWin());
-      }
+      var toggleButton = jQuery(":button").filter(":contains(Pause)")[0];
+      windmill.events.triggerMouseEvent(toggleButton, 'click', true);
+      
+      this.domExplorerOff();
       window.focus();
+      this.resetBorder(e);
     }
   };
   
   //Set the listeners for the dom explorer
   this.domExplorerOn = function() {
     
-    //Display the mouse coords in the IDE
-    fleegix.event.listen(windmill.testWin().document.body, 'onmousemove', windmill.ui.domexplorer, 'showMouseCoords');
+    jQuery("#domInspector").dialog('open');
     
+    //Display the mouse coords in the IDE
+    fleegix.event.listen(windmill.testWin().document.body, 'onmousemove', windmill.ui.dx, 'showMouseCoords');
     
     this.exploreState = true;
     try {
       $('explorer').src = 'img/xoff.png';
-      $('domExp').style.display = 'block';
       $('domExp').innerHTML = '';
       this.dxRecursiveBind(windmill.testWin());
     }
@@ -208,19 +201,25 @@ windmill.ui.domexplorer = new function() {
 
   //Remove the listeners for the dom explorer
   this.domExplorerOff = function() {
+    window.focus();
+    
+    try {
+      var toggleButton = jQuery(":button").filter(":contains(Pause)")[0];
+    
+      if (toggleButton.innerHTML == "Pause"){
+        windmill.events.triggerMouseEvent(toggleButton, 'click', true);
+      }
+    } catch(err){}
+    
     //Mouse coords display off
-    fleegix.event.unlisten(windmill.testWin().document.body, 'onmousemove', windmill.ui.domexplorer, 'showMouseCoords');
-    $('mouseExp').innerHTML = "";
+    fleegix.event.unlisten(windmill.testWin().document.body, 'onmousemove', windmill.ui.dx, 'showMouseCoords');
     this.exploreState = false;
 
     try {
       //Reset the selected element
-      windmill.ui.remote.selectedElement = null;
-      windmill.ui.remote.selectedElementOption = null;
+      windmill.ui.remote.selectedInputID = null;
       
       $('explorer').src = 'img/xon.png';
-      $('domExp').style.display = 'none';
-      $('domExp').innerHTML = '';
       this.dxRecursiveUnBind(windmill.testWin());
     }
     catch(error) {
@@ -229,7 +228,57 @@ windmill.ui.domexplorer = new function() {
       this.exploreState = false;
     }
   };
-
+  
+  this.enableFlashExplorer = function(win){
+    //turn on flex explorer if it's available
+    var embeds = win.document.getElementsByTagName("embed");
+    var objects = win.document.getElementsByTagName("object");
+    
+    //only add the explorer call back method if we have some flex on the page
+    if ((embeds.length > 0) || (objects.length > 0)){
+      win.fp_explorerSelect = function(obj){
+        $("domExp").innerHTML = "chain: "+obj;
+        return true;
+      };
+      win.fp_explorerStopped = function(obj){
+        windmill.ui.dx.domExplorerOff();
+        return true;
+      }
+    }
+    
+    //star the explorers on the page
+    for (var i=0;i<embeds.length;i++){
+      try {
+        embeds[i].fp_explorerStart();
+      } catch(err){};
+    }
+    for (var i=0;i<objects.length;i++){
+      try {
+        objects[i].fp_explorerStart();
+      } catch(err){}
+    }
+  };
+  
+  this.disableFlashExplorer = function(win){
+    //turn on flex explorer if it's available
+    var embeds = win.document.getElementsByTagName("embed");
+    var objects = win.document.getElementsByTagName("object");
+    
+    //only add the explorer call back method if we have some flex on the page
+    
+    //start the explorers on the page
+    for (var i=0;i<embeds.length;i++){
+      try {
+        embeds[i].fp_explorerStop();
+      } catch(err){}
+    }
+    for (var i=0;i<objects.length;i++){
+      try {
+        objects[i].fp_explorerStart();
+      } catch(err){}
+    }
+  };
+  
   //Recursively bind to all the iframes and frames within
   this.dxRecursiveBind = function(frame) {
     var exitEvent = "onclick";
@@ -238,11 +287,13 @@ windmill.ui.domexplorer = new function() {
     }
     
     this.dxRecursiveUnBind(frame);
-
+    
     fleegix.event.listen(frame.document, 'onmouseover', this, 'setIdInRemote');
     fleegix.event.listen(frame.document, 'onmouseout', this, 'resetBorder');
     fleegix.event.listen(frame.document, exitEvent, this, 'explorerClick');
-
+    
+    this.enableFlashExplorer(frame);
+    
     var iframeCount = frame.window.frames.length;
     var iframeArray = frame.window.frames;
 
@@ -252,6 +303,7 @@ windmill.ui.domexplorer = new function() {
         fleegix.event.listen(iframeArray[i].document, 'onmouseout', this, 'resetBorder');
         fleegix.event.listen(iframeArray[i].document, exitEvent, this, 'explorerClick');
         this.dxRecursiveBind(iframeArray[i]);
+        this.enableFlashExplorer(iframeArray[i]);
       }
       catch(error) {
         windmill.err('Binding to windows and iframes, '+error +'.. binding all others.');
@@ -265,6 +317,8 @@ windmill.ui.domexplorer = new function() {
       exitEvent = "ondblclick";
     }
     
+    this.disableFlashExplorer(frame);
+    
     fleegix.event.unlisten(frame.document, 'onmouseover', this, 'setIdInRemote');
     fleegix.event.unlisten(frame.document, 'onmouseout', this, 'resetBorder');
     fleegix.event.unlisten(frame.document, exitEvent, this, 'explorerClick');
@@ -278,6 +332,7 @@ windmill.ui.domexplorer = new function() {
         fleegix.event.unlisten(iframeArray[i].document, 'onmouseout', this, 'resetBorder');
         fleegix.event.unlisten(iframeArray[i].document, exitEvent, this, 'explorerClick');
         this.dxRecursiveUnBind(iframeArray[i]);
+        this.disableFlashExplorer(iframeArray[i]);
       }
       catch(error) {
         windmill.err('Binding to windows and iframes, '+error +'.. binding all others.');
@@ -285,4 +340,4 @@ windmill.ui.domexplorer = new function() {
     }
   };
 
-};
\ No newline at end of file
+};
