@@ -32,12 +32,13 @@ windmill.ui.results = new function() {
           var resultsDiv = $("perfOut");
           var resDiv = document.createElement('div');
           resDiv.className = "ui-state-highlight ui-corner-all outputEntry";
-          resDiv.style.height = "13px";
+          resDiv.style.height = "12px";
           // if (windmill.browser.isIE){
           //   resDiv.style.width = "95%";
           // }
        
-          resDiv.innerHTML = "<strong>"+timeObj.identifier + "</strong>&nbsp;<a href='#'>+</a>";
+          resDiv.innerHTML = "<strong>"+timeObj.identifier + "</strong>: "+newParams.RunTime+
+            "&nbsp;<a class='moreLink' href='#'>more</a>";
           for (i in newParams){
             var propDiv = document.createElement('div');
             propDiv.style.fontSize = "11px";
@@ -52,13 +53,13 @@ windmill.ui.results = new function() {
             resultsDiv.insertBefore(resDiv, jQuery(resultsDiv).children()[0]);
           }
           jQuery(resDiv).click(function() {
-              if (resDiv.style.height == "13px"){
+              if (resDiv.style.height == "12px"){
                 resDiv.style.height = "";
-                jQuery(resDiv).html(jQuery(resDiv).html().replace('+','-'));
+                jQuery(resDiv).html(windmill.helpers.replaceAll(jQuery(resDiv).html(),'more','less'));
               }
               else {
-                resDiv.style.height = "13px";
-                jQuery(resDiv).html(jQuery(resDiv).html().replace('-','+'));
+                resDiv.style.height = "12px";
+                jQuery(resDiv).html(windmill.helpers.replaceAll(jQuery(resDiv).html(),'less','more'));
               }
           });
     }
@@ -94,7 +95,7 @@ windmill.ui.results = new function() {
       // if (windmill.browser.isIE){
       //   resDiv.style.width = "95%";
       // }
-      resDiv.style.height = "13px";
+      resDiv.style.height = "12px";
       if (result){
         resDiv.className = "ui-state-highlight ui-corner-all outputEntry";
         resDiv.style.border = "1px solid darkgreen";
@@ -108,17 +109,19 @@ windmill.ui.results = new function() {
       var props = false;
       for (i in newParams){
         var propDiv = document.createElement('div');
-        propDiv.style.fontSize = "11px";
+        //propDiv.style.fontSize = "11px";
         propDiv.innerHTML = "<strong>"+i+"</strong>: "+newParams[i];
         resDiv.appendChild(propDiv);
         props = true;
       }
       
       if (props){
-        resDiv.innerHTML = "<strong>"+method + "</strong>&nbsp;+" + resDiv.innerHTML;
+        resDiv.innerHTML = "<strong>"+method + 
+          "</strong>&nbsp;<a style='color:#000;' class='moreLink' href='#'>more</a>" + 
+          resDiv.innerHTML;
       }
       else {
-        resDiv.innerHTML = "<strong>"+method + "</strong>" + resDiv.innerHTML;
+        resDiv.innerHTML = "<strong>"+method + "</strong> " + resDiv.innerHTML;
       }
       
       //Depending if there are any child nodes yet
@@ -130,13 +133,13 @@ windmill.ui.results = new function() {
       }
       
       jQuery(resDiv).click(function() {
-          if (resDiv.style.height == "13px"){
+          if (resDiv.style.height == "12px"){
             this.style.height = "";
-            jQuery(this).html(jQuery(this).html().replace('+','-'));
+            jQuery(this).html(windmill.helpers.replaceAll(jQuery(this).html(),'more','less'));
           }
           else {
-            this.style.height = "13px";
-            jQuery(this).html(jQuery(this).html().replace('-','+'));
+            this.style.height = "12px";
+            jQuery(this).html(windmill.helpers.replaceAll(jQuery(this).html(),'less','more'));
           }
       });
     }
