@@ -28,7 +28,7 @@ var windmill = new function() {
 
     this.serviceDelay = 0;
     this.serviceDelayRunning = 0;
-    this.serviceDelayDefer = 800;
+    this.serviceDelayDefer = 0;
 
     this.safeWaits = true;
     
@@ -86,6 +86,8 @@ var windmill = new function() {
     this.remote = parent.window;
     this.browser = null;
     
+    this.scriptAppendOnly = false;
+    
     //results storage if IDE isn't ready
     this.errorArr = [];
     this.out = function(s){
@@ -380,7 +382,7 @@ var windmill = new function() {
         
         //Reset the explorer and recorder to what
         //they were before the new page load
-        windmill.ui.domexplorer.setExploreState();
+        windmill.ui.dx.setExploreState();
         windmill.ui.recorder.setRecState();
 		    busyOff();
         // if we're currently running JS tests, we need to know the
@@ -415,10 +417,14 @@ var windmill = new function() {
        }
        //Just making sure the page is fully loaded
        setTimeout("cont()", 1);
+       //Resume JS tests
+       windmill.jsTest.resumeTests();
      };
 
      this.pauseLoop = function () {
        windmill.xhr.loopState = false;
+       //Pause JS tests
+       windmill.jsTest.pauseTests();
      };
     
     //windmill Options to be set
