@@ -35,9 +35,9 @@ logger = logging.getLogger(__name__)
 
 import windmill
 from windmill.server import proxy
-import wsgi_jsonrpc
-import wsgi_xmlrpc
-import wsgi_fileserver
+from windmill.dep import wsgi_jsonrpc
+from windmill.dep import wsgi_xmlrpc
+from windmill.dep import wsgi_fileserver
 
 import jsmin
 
@@ -109,7 +109,6 @@ class WindmillChooserApplication(object):
 class WindmillCompressor(object):
     """Full JavaScript Compression Library"""
     js_file_list = [
-        ('lib', 'fleegix_js', 'plugins', 'hash.js',),
         ('lib', 'firebug', 'pi.js',),
         ('lib', 'firebug', 'firebug-lite.js',),
         ('lib', 'json2.js',),
@@ -122,8 +121,9 @@ class WindmillCompressor(object):
         ('controller', 'commands.js',),
         ('controller', 'asserts.js',),
         ('controller', 'waits.js',),
-        ('extensions', 'extensions.js',),
+        ('controller', 'flex.js',),
         ('wm', 'registry.js',),
+        ('extensions', 'extensions.js',),
         ('wm', 'utils.js',),
         ('wm', 'ide', 'ui.js',),
         ('wm', 'ide', 'recorder.js',),
